==> 1.1.0.tar.gz: lib/src/gen_translation.dart <==
import 'dart:collection';
import 'dart:convert';
import 'dart:io';

import 'package:translator/translator.dart';
import 'package:yaml/yaml.dart';

void genTranslation() async {
  final pubspecYaml = File('pubspec.yaml');
  if (!pubspecYaml.existsSync()) {
    throw Exception('No pubspec.yaml exists in your current directory');
  }

  final pubspec = loadYaml(pubspecYaml.readAsStringSync());
  final YamlList languages = pubspec['languages'] ?? ['en', 'id'];

  final l10nYaml = File('l10n.yaml');
  if (!l10nYaml.existsSync()) {
    throw Exception('No l10n.yaml exists in your project');
  }

  final translator = GoogleTranslator();

  final config = loadYaml(l10nYaml.readAsStringSync());
  final String arbDir = config['arb-dir'] ?? 'lib/l10n';
  final String templateArbFile = config['template-arb-file'] ?? 'app_en.arb';
  var templateName =
      templateArbFile.substring(0, templateArbFile.lastIndexOf('_'));

  var defaultLang = templateArbFile.replaceAll('.arb', '');
  defaultLang = defaultLang.substring(defaultLang.lastIndexOf('_') + 1);

  final defaultArb = File('$arbDir/$templateArbFile');
  final defaultArbData =
      json.decode(defaultArb.readAsStringSync()) as Map<String, dynamic>;

  final encoder = JsonEncoder.withIndent('    ');

  for (var lang in languages.where((element) => element != defaultLang)) {
    final newArb = File('$arbDir/${templateName}_$lang.arb');
    var arbData = <String, dynamic>{};
    if (newArb.existsSync()) {
      arbData = json.decode(newArb.readAsStringSync());
    }

    for (var key in defaultArbData.keys) {
      if (arbData.containsKey(key)) continue;

      final String source = defaultArbData[key];
      final translation = await translator.translate(
        source,
        from: defaultLang,
        to: lang,
      );

      arbData[key] = translation.text;
    }

    var sorted = SplayTreeMap.from(arbData);
    newArb.writeAsStringSync(encoder.convert(sorted), flush: true);
  }

  await Process.run('flutter', ['gen-l10n']);
}

==> 1.1.1.tar.gz: lib/src/gen_translation.dart <==
import 'dart:collection';
import 'dart:convert';
import 'dart:io';

import 'package:translator/translator.dart';
import 'package:yaml/yaml.dart';

void genTranslation() async {
  final pubspecYaml = File('pubspec.yaml');
  if (!pubspecYaml.existsSync()) {
    throw Exception('No pubspec.yaml exists in your current directory');
  }

  final pubspec = loadYaml(pubspecYaml.readAsStringSync());
  final YamlList languages = pubspec['languages'] ?? ['en', 'id'];

  final l10nYaml = File('l10n.yaml');
  if (!l10nYaml.existsSync()) {
    throw Exception('No l10n.yaml exists in your project');
  }

  final translator = GoogleTranslator();

  final config = loadYaml(l10nYaml.readAsStringSync());
  final String arbDir = config['arb-dir'] ?? 'lib/l10n';
  final String templateArbFile = config['template-arb-file'] ?? 'app_en.arb';
  var templateName =
      templateArbFile.substring(0, templateArbFile.lastIndexOf('_'));

  var defaultLang = templateArbFile.replaceAll('.arb', '');
  defaultLang = defaultLang.substring(defaultLang.lastIndexOf('_') + 1);

  final defaultArb = File('$arbDir/$templateArbFile');
  final defaultArbData =
      json.decode(defaultArb.readAsStringSync()) as Map<String, dynamic>;

  final encoder = JsonEncoder.withIndent('    ');

  for (String lang in languages.where((element) => element != defaultLang)) {
    final newArb = File('$arbDir/${templateName}_$lang.arb');
    var arbData = <String, dynamic>{};
    if (newArb.existsSync()) {
      arbData = json.decode(newArb.readAsStringSync());
    }

    for (var key in defaultArbData.keys) {
      if (arbData.containsKey(key)) continue;

      final String source = defaultArbData[key];
      final translation = await translator.translate(
        source,
        from: defaultLang,
        to: lang.toLowerCase().replaceAll('_', '-'),
      );

      arbData[key] = translation.text;
    }

    var sorted = SplayTreeMap.from(arbData);
    newArb.writeAsStringSync(encoder.convert(sorted), flush: true);
  }

  await Process.run('flutter', ['gen-l10n']);
}
